@@ -232,7 +232,7 @@ def aux_data_to_p0_e0(data, aux_data):
         p0[:, :] = aux_data["value"]
         e0[:, :] = p0[:, :] * aux_data["error_scale"]
     elif aux_data["type"] == "mmap":
-        mmap = np.memmap(aux_data["value"], dtype=np.float, mode="r", shape=shape)
+        mmap = np.memmap(aux_data["value"], dtype=float, mode="r", shape=shape)
         p0[:, :] = mmap[:, :]
         e0[:, :] = p0[:, :] * aux_data["error_scale"]
     else:
@@ -297,7 +297,7 @@ def rho_models_to_kwargs(rtfo, rho_model, wvls, logger):
                 logger.info("Slice given, use wvls and slice: %s" % str(rho_model["rho_wvl"]))
                 rho_wvl = copy(wvls[rho_model["rho_wvl"]])
             else:
-                rho_wvl = np.array(rho_model["rho_wvl"], dtype=np.float)
+                rho_wvl = np.array(rho_model["rho_wvl"], dtype=float)
         except Exception:
             logger.info("Rho_wvl not given for linear model, take all wvls.")
             rho_wvl = copy(wvls[::1])
@@ -374,18 +374,18 @@ def get_instruments(rtfo, metadata=None, expand_wvl=20.0, wvl_rsp_resolution=0.2
 # noinspection PyGlobalUndefined,PyShadowingNames
 def get_output_fields(data):
     global args, settings, logger, memmaps
-    data_atmosphere_fields = np.zeros(list(data.shape[:2]) + [settings["n_atm_fields"]], dtype=np.float)
+    data_atmosphere_fields = np.zeros(list(data.shape[:2]) + [settings["n_atm_fields"]], dtype=float)
     if args["use_memory"] is True:
         logger.info("Store all resulting fields in Memory.")
-        data_surface_reflectance = np.zeros(data.shape, dtype=np.float)
-        data_surface_reflectance_model = np.zeros(data.shape, dtype=np.float)
+        data_surface_reflectance = np.zeros(data.shape, dtype=float)
+        data_surface_reflectance_model = np.zeros(data.shape, dtype=float)
     else:
         logger.info("Use memmap objects to store resulting fields.")
         data_surface_reflectance = np.memmap(
-            "%sdata_surface_reflectance_%s.memmap" % (args["memmap_dir"], args["now_timestring"]), dtype=np.float,
+            "%sdata_surface_reflectance_%s.memmap" % (args["memmap_dir"], args["now_timestring"]), dtype=float,
             mode='w+', shape=data.shape)
         data_surface_reflectance_model = np.memmap(
-            "%sata_surface_reflectance_model_%s.memmap" % (args["memmap_dir"], args["now_timestring"]), dtype=np.float,
+            "%sata_surface_reflectance_model_%s.memmap" % (args["memmap_dir"], args["now_timestring"]), dtype=float,
             mode='w+', shape=data.shape)
         memmaps.append(data_surface_reflectance)
         memmaps.append(data_surface_reflectance_model)
@@ -481,19 +481,19 @@ def sample_optimization_and_upscale_results(data, p0):
         default_value = -999.0
         flag = settings["fo_instances"][settings["default_fo"]]["flag"]
         logger.info("Use sample points estimates to upscale estimate for whole image.")
-        ii_spec_i1 = np.linspace(0, data.shape[0] - 1, settings["nn_spec_i1"], dtype=np.int)
-        ii_spec_i2 = np.linspace(0, data.shape[1] - 1, settings["nn_spec_i2"], dtype=np.int)
+        ii_spec_i1 = np.linspace(0, data.shape[0] - 1, settings["nn_spec_i1"], dtype=int)
+        ii_spec_i2 = np.linspace(0, data.shape[1] - 1, settings["nn_spec_i2"], dtype=int)
         logger.info("Using %i,%i samples." % (settings["nn_spec_i1"], settings["nn_spec_i2"]))
 
         pt_spec = default_value * np.ones(
             (settings["nn_spec_i1"], settings["nn_spec_i2"], len(fos[settings["default_fo"]].pt_dims)))
-        zoom_fac = [np.float(ss) / np.float(nn) for ss, nn in
+        zoom_fac = [float(ss) / float(nn) for ss, nn in
                     zip(p0.shape[:2], [settings["nn_spec_i1"], settings["nn_spec_i2"]])]
         logger.info("Zoom factors are: %.2f,%.2f" % tuple(zoom_fac))
         logger.info("Upscaling is used for:" + str(settings["guess_dims_upscale"]))
         upscale_ind = np.array(
             [ii for ii, dim in enumerate(fos[settings["default_fo"]].pt_dims) if dim in settings["guess_dims_upscale"]],
-            dtype=np.int)
+            dtype=int)
         logger.info("Upscale indices are: " + str(upscale_ind))
 
         for s1, i1 in tqdm(enumerate(ii_spec_i1), total=len(ii_spec_i1)):
@@ -590,7 +590,7 @@ def get_pt_names_and_indexes(fos, settings):
                 pt_names.append(dim)
     pt_indexes = {}
     for fo_name, fo in fos.items():
-        pt_indexes[fo_name] = np.array([pt_names.index(dim) for dim in fo.pt_dims], dtype=np.int)
+        pt_indexes[fo_name] = np.array([pt_names.index(dim) for dim in fo.pt_dims], dtype=int)
 
     pt_names = np.array(pt_names)
 
@@ -599,10 +599,10 @@ def get_pt_names_and_indexes(fos, settings):
     for fo_name, fo_dfs in settings["fo_instances"].items():
         flag_to_indexes_res[fo_dfs["flag"]] = np.array(
             [ii for ii, name in enumerate(pt_names[pt_indexes[fo_name]]) if name in settings["atm_fields"]],
-            dtype=np.int)
+            dtype=int)
         flag_to_indexes_common[fo_dfs["flag"]] = np.array(
             [settings["atm_fields"].index(name) for ii, name in enumerate(pt_names[pt_indexes[fo_name]]) if
-             name in settings["atm_fields"]], dtype=np.int)
+             name in settings["atm_fields"]], dtype=int)
 
     return (pt_names,
             pt_indexes,
