@@ -28,7 +28,7 @@ import logging
 import numpy as np
 import pandas as pd
 import dill
-from multiprocessing import Pool
+import multiprocessing as mp
 from itertools import product
 from time import time
 import warnings
@@ -41,8 +41,8 @@ import platform
 from py_tools_ds.processing.progress_mon import ProgressBar
 
 from sicor.Tools.EnMAP.metadata import varsol
-from sicor.Tools.EnMAP.LUT import get_data_file, read_lut_enmap_formatted, download_LUT, interpol_lut_c
-from sicor.Tools.EnMAP.LUT import reduce_lut, interpol_lut_c_red
+from sicor.Tools.EnMAP.LUT import get_data_file, read_lut_enmap_formatted, download_LUT, interpol_lut
+from sicor.Tools.EnMAP.LUT import reduce_lut, interpol_lut_red
 from sicor.Tools.EnMAP.conversion import generate_filter, table_to_array
 from sicor.Tools.EnMAP.optimal_estimation import invert_function
 from sicor.Tools.EnMAP.multiprocessing import SharedNdarray, initializer, mp_progress_bar
@@ -284,14 +284,8 @@ class FoGen(object):
         # LUT interpolation
         vtest = np.asarray([pt[0], pt[1], pt[2], pt[3], pt[4], xx[0]])
 
-        f_int = interpol_lut_c(lut1=self.lut1_fit,
-                               lut2=self.lut2_fit,
-                               xnodes=self.xnodes,
-                               nm_nodes=self.nm_nodes,
-                               ndim=self.ndim,
-                               x_cell=self.x_cell,
-                               vtest=vtest,
-                               intp_wvl=self.wvl_sel)
+        f_int = interpol_lut(lut1=self.lut1_fit, lut2=self.lut2_fit, xnodes=self.xnodes, nm_nodes=self.nm_nodes,
+                             ndim=self.ndim, x_cell=self.x_cell, vtest=vtest, intp_wvl=self.wvl_sel)
 
         f_int_l0 = f_int[0, :] * 1.e+3
         f_int_edir = f_int[1, :] * 1.e+3
@@ -326,23 +320,11 @@ class FoGen(object):
         vtest = np.asarray([pt[0], pt[1], pt[2], pt[3], pt[4], xx[0]])
 
         if mode == "full":
-            f_int = interpol_lut_c(lut1=self.lut1_full,
-                                   lut2=self.lut2_full,
-                                   xnodes=self.xnodes,
-                                   nm_nodes=self.nm_nodes,
-                                   ndim=self.ndim,
-                                   x_cell=self.x_cell,
-                                   vtest=vtest,
-                                   intp_wvl=self.wvl)
+            f_int = interpol_lut(lut1=self.lut1_full, lut2=self.lut2_full, xnodes=self.xnodes, nm_nodes=self.nm_nodes,
+                                 ndim=self.ndim, x_cell=self.x_cell, vtest=vtest, intp_wvl=self.wvl)
         else:
-            f_int = interpol_lut_c(lut1=self.lut1_fit,
-                                   lut2=self.lut2_fit,
-                                   xnodes=self.xnodes,
-                                   nm_nodes=self.nm_nodes,
-                                   ndim=self.ndim,
-                                   x_cell=self.x_cell,
-                                   vtest=vtest,
-                                   intp_wvl=self.wvl_sel)
+            f_int = interpol_lut(lut1=self.lut1_fit, lut2=self.lut2_fit, xnodes=self.xnodes, nm_nodes=self.nm_nodes,
+                                 ndim=self.ndim, x_cell=self.x_cell, vtest=vtest, intp_wvl=self.wvl_sel)
 
         f_int_l0 = f_int[0, :] * 1.e+3 * self.fac
         f_int_edir = f_int[1, :] * 1.e+3 * self.fac
@@ -606,23 +588,43 @@ class Fo(object):
         self.wvl_swir = np.array(enmap_l1b.swir.detector_meta.wvl_center[:])
         self.fwhm_swir = np.array(enmap_l1b.swir.detector_meta.fwhm[:])
 
-        # get solar irradiances for absorption feature shoulders wavelengths
-        self.logger.info("Getting solar irradiances for absorption feature shoulders wavelengths...")
-        new_kur_fn = get_data_file(module_name="sicor", file_basename="newkur_EnMAP.dat")
-        new_kur = pd.read_csv(new_kur_fn, delim_whitespace=True)
-        freq_0 = 10e6 / self.wvl_sel[0]
-        freq_1 = 10e6 / self.wvl_sel[-1]
-        solar_0 = np.zeros(1)
-        solar_1 = np.zeros(1)
+        # load solar irradiance model
+        self.logger.info("Loading solar irradiance model...")
+        self.sol_model = options["retrieval"]["sol_model"]
 
-        for ii in range(1, new_kur.shape[0]):
-            if int(freq_0) - int(new_kur.at[ii, "FREQ"]) == 0:
-                solar_0 = new_kur.at[ii, "SOLAR"]
-            if int(freq_1) - int(new_kur.at[ii, "FREQ"]) == 0:
-                solar_1 = new_kur.at[ii, "SOLAR"]
+        try:
+            assert self.sol_model == "new_kurucz" or self.sol_model == "fontenla"
+        except AssertionError:
+            raise AssertionError("No valid solar model is provided. Please indicate either 'new_kurucz' or 'fontenla' "
+                                 "in the options file.")
 
-        self.s0 = float(solar_0) * (10e6 / self.wvl_sel[0]) ** 2
-        self.s1 = float(solar_1) * (10e6 / self.wvl_sel[-1]) ** 2
+        if self.sol_model == "new_kurucz":
+            new_kur_fn = get_data_file(module_name="sicor", file_basename="newkur_EnMAP.dat")
+            new_kur = pd.read_csv(new_kur_fn, delim_whitespace=True)
+            new_kur_wvl = 10e6 / np.asarray(new_kur["FREQ"][1:], dtype=float)
+            new_kur_sol = np.asarray(new_kur["SOLAR"][1:], dtype=float) * (10e6 / new_kur_wvl) ** 2
+            self.solar_lut = {"wvl": new_kur_wvl, "sol_irr": new_kur_sol}
+
+            # get solar irradiances for shoulders of 1140 nm water absorption feature
+            s_norm_new_kur_fit = generate_filter(wvl_m=new_kur_wvl, wvl=self.wvl_sel, wl_resol=self.fwhm_sel)
+            new_kur_sol_fit = new_kur_sol @ s_norm_new_kur_fit
+
+            self.s0 = new_kur_sol_fit[0]
+            self.s1 = new_kur_sol_fit[-1]
+
+        elif self.sol_model == "fontenla":
+            fon_fn = get_data_file(module_name="sicor", file_basename="fontenla_EnMAP.dat")
+            fon = pd.read_csv(fon_fn, delim_whitespace=True)
+            fon_wvl = np.asarray(fon["um=micron"], dtype=float) * 1000
+            fon_sol = np.asarray(fon["E0"], dtype=float) * 10
+            self.solar_lut = {"wvl": fon_wvl, "sol_irr": fon_sol}
+
+            # get solar irradiances for shoulders of 1140 nm water absorption feature
+            s_norm_fon_fit = generate_filter(wvl_m=fon_wvl, wvl=self.wvl_sel, wl_resol=self.fwhm_sel)
+            new_kur_sol_fit = fon_sol @ s_norm_fon_fit
+
+            self.s0 = new_kur_sol_fit[0]
+            self.s1 = new_kur_sol_fit[-1]
 
         # load RT LUT
         # check if LUT file is available
@@ -655,6 +657,33 @@ class Fo(object):
         self.ndim = ndim
         self.x_cell = x_cell
 
+        # applying spectral conversion factor to LUT in case Fontenla solar model is to be used
+        if self.sol_model == "fontenla":
+            self.logger.info("Converting LUT to Fontenla solar model...")
+            path_conv_fac = get_data_file(module_name="sicor", file_basename="conv_fac_fon_lut.dill")
+
+            with open(path_conv_fac, "rb") as fl:
+                conv_fac_fon_lut = dill.load(fl)
+
+            lut1_fon = np.zeros(lut1.shape)
+            lut2_fon = np.zeros(lut2.shape)
+
+            for ii in range(5):
+                for jj in range(6):
+                    for kk in range(4):
+                        for ll in range(6):
+                            for mm in range(7):
+                                lut1_fon[ii, jj, kk, ll, mm, 0, :, 0] = lut1[ii, jj, kk, ll, mm, 0, :, 0] * \
+                                                                        conv_fac_fon_lut
+                                for nn in range(2):
+                                    lut2_fon[ii, jj, kk, ll, 0, mm, :, nn] = lut2[ii, jj, kk, ll, 0, mm, :, nn] * \
+                                                                             conv_fac_fon_lut
+            for ii in range(2):
+                lut2_fon[:, :, :, :, :, :, :, ii + 2] = lut2[:, :, :, :, :, :, :, ii + 2]
+
+            lut1 = lut1_fon
+            lut2 = lut2_fon
+
         # resampling LUT to EnMAP wavelengths
         self.logger.info("Resampling LUT to EnMAP wavelengths...")
 
@@ -715,45 +744,28 @@ class Fo(object):
         self.abs_co_w = 4 * np.pi * self.kw / self.wvl_sel
         self.abs_co_i = 4 * np.pi * self.ki / self.wvl_sel
 
-        # calculate mean solar exoatmospheric irradiances
-        self.logger.info("Calculating mean solar exoatmospheric irradiances...")
-        path_sol = get_data_file(module_name="sicor", file_basename="solar_irradiances_400_2500_1.dill")
-
-        with open(path_sol, "rb") as fl:
-            solar_lut = dill.load(fl)
-
-        self.solar_res = solar_lut @ self.s_norm_fit
-
         # perform first guess water vapor retrieval based on a common band ratio using VNIR data
         warnings.filterwarnings("ignore")
         if self.use_prior_mean[0]:
             self.cwv_fg = np.full(self.data_vnir.shape[:2], self.prior_mean[0])
         else:
             logger.info("Performing first guess water vapor retrieval based on a common band ratio using VNIR data...")
-            self.cwv_fg = wv_band_ratio(data=self.data_vnir,
-                                        water_msk=self.water_mask_vnir,
-                                        land_only=self.land_only,
-                                        fn_table=self.fn_table,
-                                        vza=self.pt[:, :, 0].mean(),
-                                        sza=self.pt[:, :, 1].mean(),
-                                        dem=self.hsf["vnir"].mean(),
-                                        aot=self.pt[:, :, 3].mean(),
-                                        raa=self.pt[:, :, 4].mean(),
-                                        intp_wvl=self.wvl_vnir,
-                                        intp_fwhm=self.fwhm_vnir,
-                                        jday=self.jday,
-                                        month=self.month,
-                                        idx=[73, 76, 81],
+            self.cwv_fg = wv_band_ratio(data=self.data_vnir, water_msk=self.water_mask_vnir, fn_table=self.fn_table,
+                                        sol_model=self.solar_lut, vza=self.pt[:, :, 0].mean(),
+                                        sza=self.pt[:, :, 1].mean(), dem=self.hsf["vnir"].mean(),
+                                        aot=self.pt[:, :, 3].mean(), raa=self.pt[:, :, 4].mean(),
+                                        intp_wvl=self.wvl_vnir, intp_fwhm=self.fwhm_vnir, jday=self.jday,
+                                        month=self.month, idx=[73, 76, 81], processes=self.cpu,
                                         disable=self.disable_progressbars)
 
             self.cwv_fg[np.logical_or(np.isnan(self.cwv_fg), np.isinf(self.cwv_fg))] = self.prior_mean[0]
+            self.cwv_fg[self.water_mask_vnir != 1] = self.prior_mean[0]
 
         # transform CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval
         logger.info("Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of "
                     "water retrieval...")
         self.cwv_fg_trans = enmap_l1b.transform_vnir_to_swir_raster(array_vnirsensorgeo=self.cwv_fg,
-                                                                    resamp_alg=self.resamp_alg,
-                                                                    respect_keystone=False)
+                                                                    resamp_alg=self.resamp_alg, respect_keystone=False)
 
         self.cwv_fg_trans[self.cwv_fg_trans == 0.0] = self.prior_mean[0]
 
@@ -815,8 +827,7 @@ class Fo(object):
 
         if self.segmentation:
             self.logger.info("Segmenting SWIR L1B spectra to enhance processing speed...")
-            self.X, self.segs, self.labels = SLIC_segmentation(data_rad_all=self.data_swir,
-                                                               n_pca=self.n_pca,
+            self.X, self.segs, self.labels = SLIC_segmentation(data_rad_all=self.data_swir, n_pca=self.n_pca,
                                                                segs=self.segs)
 
             # prepare segmented SWIR L1B data cube
@@ -886,9 +897,9 @@ class Fo(object):
         # LUT interpolation
         vtest = np.asarray([pt[2], xx[0]])
 
-        f_int = interpol_lut_c_red(lut1=self.lut_red_fit[:, :, :, 0], lut2=self.lut_red_fit[:, :, :, 1:],
-                                   xnodes=self.xnodes_red, nm_nodes=self.nm_nodes_red, ndim=self.ndim_red,
-                                   x_cell=self.x_cell_red, vtest=vtest, intp_wvl=self.wvl_sel)
+        f_int = interpol_lut_red(lut1=self.lut_red_fit[:, :, :, 0], lut2=self.lut_red_fit[:, :, :, 1:],
+                                 xnodes=self.xnodes_red, nm_nodes=self.nm_nodes_red, ndim=self.ndim_red,
+                                 x_cell=self.x_cell_red, vtest=vtest, intp_wvl=self.wvl_sel)
 
         f_int_l0 = f_int[0, :] * 1.e+3
         f_int_edir = f_int[1, :] * 1.e+3
@@ -923,17 +934,17 @@ class Fo(object):
         vtest = np.asarray([pt[2], xx])
 
         if mode == "vnir":
-            f_int = interpol_lut_c_red(lut1=self.lut_red_vnir[:, :, :, 0], lut2=self.lut_red_vnir[:, :, :, 1:],
-                                       xnodes=self.xnodes_red, nm_nodes=self.nm_nodes_red, ndim=self.ndim_red,
-                                       x_cell=self.x_cell_red, vtest=vtest, intp_wvl=self.wvl_vnir)
+            f_int = interpol_lut_red(lut1=self.lut_red_vnir[:, :, :, 0], lut2=self.lut_red_vnir[:, :, :, 1:],
+                                     xnodes=self.xnodes_red, nm_nodes=self.nm_nodes_red, ndim=self.ndim_red,
+                                     x_cell=self.x_cell_red, vtest=vtest, intp_wvl=self.wvl_vnir)
         elif mode == "swir":
-            f_int = interpol_lut_c_red(lut1=self.lut_red_swir[:, :, :, 0], lut2=self.lut_red_swir[:, :, :, 1:],
-                                       xnodes=self.xnodes_red, nm_nodes=self.nm_nodes_red, ndim=self.ndim_red,
-                                       x_cell=self.x_cell_red, vtest=vtest, intp_wvl=self.wvl_swir)
+            f_int = interpol_lut_red(lut1=self.lut_red_swir[:, :, :, 0], lut2=self.lut_red_swir[:, :, :, 1:],
+                                     xnodes=self.xnodes_red, nm_nodes=self.nm_nodes_red, ndim=self.ndim_red,
+                                     x_cell=self.x_cell_red, vtest=vtest, intp_wvl=self.wvl_swir)
         else:
-            f_int = interpol_lut_c_red(lut1=self.lut_red_fit[:, :, :, 0], lut2=self.lut_red_fit[:, :, :, 1:],
-                                       xnodes=self.xnodes_red, nm_nodes=self.nm_nodes_red, ndim=self.ndim_red,
-                                       x_cell=self.x_cell_red, vtest=vtest, intp_wvl=self.wvl_sel)
+            f_int = interpol_lut_red(lut1=self.lut_red_fit[:, :, :, 0], lut2=self.lut_red_fit[:, :, :, 1:],
+                                     xnodes=self.xnodes_red, nm_nodes=self.nm_nodes_red, ndim=self.ndim_red,
+                                     x_cell=self.x_cell_red, vtest=vtest, intp_wvl=self.wvl_sel)
 
         f_int_l0 = f_int[0, :] * 1.e+3 * self.fac
         f_int_edir = f_int[1, :] * 1.e+3 * self.fac
@@ -1127,9 +1138,7 @@ def __minimize__(fo, opt_func, unknowns=False, logger=None):
 
     if platform.system() == "Windows" and processes > 1:
         logger.warning('Multiprocessing is currently not available on Windows.')
-    if platform.system() == "Darwin" and processes > 1:
-        logger.warning('Multiprocessing is currently not available on macOS.')
-    if platform.system() == "Windows" or platform.system() == "Darwin" or processes == 1:
+    if platform.system() == "Windows" or processes == 1:
         logger.info("Singleprocessing on 1 cpu")
     else:
         logger.info("Setting up multiprocessing...")
@@ -1231,14 +1240,15 @@ def __minimize__(fo, opt_func, unknowns=False, logger=None):
     # start optimization
     logger.info("Optimization...")
     t0 = time()
+
     # check if operating system is 'Windows'; in that case, multiprocessing is currently not working
     # TODO: enable Windows compatibility for multiprocessing
-
-    if platform.system() == "Windows" or platform.system() == "Darwin" or processes == 1:
+    if platform.system() == "Windows" or processes == 1:
         initializer(globals(), globs)
         [mp_fun(ii) for ii in tqdm(rng, disable=fo.disable_progressbars)]
     else:
-        with closing(Pool(processes=processes, initializer=initializer, initargs=(globals(), globs,))) as pl:
+        with closing(mp.get_context("fork").Pool(processes=processes, initializer=initializer, initargs=(globals(),
+                                                                                                         globs))) as pl:
             results = pl.map_async(mp_fun, rng, chunksize=1)
             if not fo.disable_progressbars:
                 bar = ProgressBar(prefix='\tprogress:')
@@ -1354,25 +1364,11 @@ def __oe__(ii):
             __retrieval_noise__[i1, i2, :, :] = np.full((__state_dim__, __state_dim__), np.nan)
             __smoothing_error__[i1, i2, :, :] = np.full((__state_dim__, __state_dim__), np.nan)
     else:
-        se = __calc_se__(xx=__xa__[i1, i2, :],
-                         dt=__data__[i1, i2, :],
-                         pt=__pt__[i1, i2, :],
-                         sb=__sb__,
-                         num_bd=len(__fit_wvl__),
-                         snr=__snr__,
-                         unknowns=__unknowns__)
+        se = __calc_se__(xx=__xa__[i1, i2, :], dt=__data__[i1, i2, :], pt=__pt__[i1, i2, :], sb=__sb__,
+                         num_bd=len(__fit_wvl__), snr=__snr__, unknowns=__unknowns__)
 
-        res = __inv_func__(yy=__data__[i1, i2, :],
-                           fparam=__pt__[i1, i2, :],
-                           ll=__ll__,
-                           ul=__ul__,
-                           xa=__xa__[i1, i2, :],
-                           sa=__sa__,
-                           se=se,
-                           gnform=__gnform__,
-                           full=__full__,
-                           maxiter=__maxiter__,
-                           eps=__eps__)
+        res = __inv_func__(yy=__data__[i1, i2, :], fparam=__pt__[i1, i2, :], ll=__ll__, ul=__ul__, xa=__xa__[i1, i2, :],
+                           sa=__sa__, se=se, gnform=__gnform__, full=__full__, maxiter=__maxiter__, eps=__eps__)
 
         model = __forward__(xx=res[0], pt=__pt__[i1, i2, :], dt=__data__[i1, i2, :], model_output=True)
 
