@@ -138,19 +138,19 @@ def __intp_spectral__(data, res, grad, ndim,
                                                                 p10 - i10) * 1.0)
                                                     # works only in numba since the integer conversion of the b is
                                                     # handled trough the interface block, without
-                                                    # numba add np.int()'s here
-                                                    b0 = np.int(i0 + sign(p0 - i0))
-                                                    b1 = np.int(i1 + sign(p1 - i1))
-                                                    b2 = np.int(i2 + sign(p2 - i2))
-                                                    b3 = np.int(i3 + sign(p3 - i3))
-                                                    b4 = np.int(i4 + sign(p4 - i4))
-                                                    b5 = np.int(i5 + sign(p5 - i5))
-                                                    b6 = np.int(i6 + sign(p6 - i6))
-                                                    b7 = np.int(i7 + sign(p7 - i7))
-                                                    b8 = np.int(i8 + sign(p8 - i8))
-                                                    b9 = np.int(i9 + sign(p9 - i9))
-                                                    b10 = np.int(i10 + sign(p10 - i10))
-                                                    b11 = np.int(i11 + sign(p11 - i11))
+                                                    # numba add int()'s here
+                                                    b0 = int(i0 + sign(p0 - i0))
+                                                    b1 = int(i1 + sign(p1 - i1))
+                                                    b2 = int(i2 + sign(p2 - i2))
+                                                    b3 = int(i3 + sign(p3 - i3))
+                                                    b4 = int(i4 + sign(p4 - i4))
+                                                    b5 = int(i5 + sign(p5 - i5))
+                                                    b6 = int(i6 + sign(p6 - i6))
+                                                    b7 = int(i7 + sign(p7 - i7))
+                                                    b8 = int(i8 + sign(p8 - i8))
+                                                    b9 = int(i9 + sign(p9 - i9))
+                                                    b10 = int(i10 + sign(p10 - i10))
+                                                    b11 = int(i11 + sign(p11 - i11))
                                                     # when writing, numba didn't support array striding,
                                                     # meant is: res[:] += vi*data[:,b0,b1,b2]
                                                     for ii in range(ndim):
@@ -210,8 +210,8 @@ def __intp_spectral_no_jac__(data, res, ndim,
 
                                                     # works only in numba since the integer conversion of the b is
                                                     # handled trough the interface block, without numba
-                                                    # add np.int()'s here
-                                                    b0 = np.int(i0 + sign(p0 - i0))
+                                                    # add int()'s here
+                                                    b0 = int(i0 + sign(p0 - i0))
                                                     b1 = np.int(i1 + sign(p1 - i1))
                                                     b2 = np.int(i2 + sign(p2 - i2))
                                                     b3 = np.int(i3 + sign(p3 - i3))
@@ -237,18 +237,18 @@ def __intp__(data, pt, dv, jacobean):
     pt: 1D numpy array of shape (3), this is the wanted interpolation point
     return: interpolated value
     """
-    d0 = np.zeros(2, dtype=np.int)
-    d1 = np.zeros(2, dtype=np.int)
-    d2 = np.zeros(2, dtype=np.int)
-    d3 = np.zeros(2, dtype=np.int)
-    d4 = np.zeros(2, dtype=np.int)
-    d5 = np.zeros(2, dtype=np.int)
-    d6 = np.zeros(2, dtype=np.int)
-    d7 = np.zeros(2, dtype=np.int)
-    d8 = np.zeros(2, dtype=np.int)
-    d9 = np.zeros(2, dtype=np.int)
-    d10 = np.zeros(2, dtype=np.int)
-    d11 = np.zeros(2, dtype=np.int)
+    d0 = np.zeros(2, dtype=int)
+    d1 = np.zeros(2, dtype=int)
+    d2 = np.zeros(2, dtype=int)
+    d3 = np.zeros(2, dtype=int)
+    d4 = np.zeros(2, dtype=int)
+    d5 = np.zeros(2, dtype=int)
+    d6 = np.zeros(2, dtype=int)
+    d7 = np.zeros(2, dtype=int)
+    d8 = np.zeros(2, dtype=int)
+    d9 = np.zeros(2, dtype=int)
+    d10 = np.zeros(2, dtype=int)
+    d11 = np.zeros(2, dtype=int)
     __dx__(pt[0], d0, data.shape[0])
     __dx__(pt[1], d1, data.shape[1])
     __dx__(pt[2], d2, data.shape[2])
