@@ -11,7 +11,7 @@ from time import sleep, time
 from types import MethodType
 from types import SimpleNamespace
 from xml.dom.minidom import parseString
-import gdal
+from osgeo import gdal
 import mpld3
 import PIL
 import numpy as np
