@@ -111,11 +111,11 @@ def sicor_ac_enmap(enmap_l1b, options, unknowns=False, logger=None):
                                                                respect_keystone=False)
 
         logger.info("Segmenting VNIR data cube according to transformed SWIR segmentation labels...")
-        vnir_rdn_subset = np.zeros((1, labels_trans.max(), fo_enmap.data_vnir.shape[2]))
-        vnir_cwv_subset = np.zeros((1, labels_trans.max()))
-        vnir_pt_subset = np.zeros((1, labels_trans.max(), fo_enmap.pt_vnir.shape[2]))
+        vnir_rdn_subset = np.zeros((1, np.unique(labels_trans).shape[0], fo_enmap.data_vnir.shape[2]))
+        vnir_cwv_subset = np.zeros((1, np.unique(labels_trans).shape[0]))
+        vnir_pt_subset = np.zeros((1, np.unique(labels_trans).shape[0], fo_enmap.pt_vnir.shape[2]))
 
-        for ii in range(labels_trans.max()):
+        for ii in range(np.unique(labels_trans).shape[0]):
             if np.count_nonzero(labels_trans == ii) == 0:
                 pass
             else:
@@ -240,6 +240,12 @@ def sicor_ac_enmap(enmap_l1b, options, unknowns=False, logger=None):
     del enmap_l1b.vnir.data_l2a
     del enmap_l1b.swir.data_l2a
 
-    logger.info("%s atmospheric correction successfully finished!" % options["sensor"]["name"])
+    if fo_enmap.land_only:
+        mode = "combined"
+    else:
+        mode = "land"
+
+    logger.info("SICOR atmospheric correction for %s in %s mode successfully finished!" % (options["sensor"]["name"],
+                                                                                           mode))
 
     return enmap_l2a_vnir, enmap_l2a_swir, res
